GOST28147Engine class

Constructors

GOST28147Engine()

Properties

AlgorithmName String
no setter
BlockSize int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init(bool forEncryption, CipherParameters params) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processBlock(List<int> inp, int inOff, List<int> out, int outOff) int
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

sBoxes Map<String, List<int>>
getter/setter pair

Static Methods

addSBox(String sBoxName, List<int> sBox) → void
getSBox(String sBoxName) List<int>

Constants

BLOCK_SIZE → const int