OzDSt1106Digest class

Constructors

OzDSt1106Digest(List<int> sBoxParam)

Properties

AlgorithmName String
no setter
ByteLength int
no setter
DigestSize int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

doFinal(List<int> out, int outOff) int
finish() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited
updateBuffer(List<int> inp, int inOff, int len) → void
updateByte(int inp) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited