ParametersWithSBox class
- Inheritance
-
- Object
- CipherParameters
- ParametersWithSBox
Constructors
-
ParametersWithSBox(CipherParameters? _parameters, List<
int> _sBox)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- Parameters → CipherParameters?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
SBox
→ List<
int> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited